# symgo
Geometry optimization under constraint of crystal symmetry

The initial code was forked from `pypolymlp:src/pypolymlp/calculator/str_opt/optimization.py` [36cd3f7](https://github.com/sekocha/pypolymlp/commit/36cd3f74d31c123f6c193ccc834b1b5ba1958550).
